@@ -1260,4 +1260,8 @@ public abstract class DB implements Codes {
             reset(commitPtr);
         }
     }
+
+    public abstract byte[] serialize(String schema) throws SQLException;
+
+    public abstract void deserialize(String schema, byte[] buff) throws SQLException;
 }
