@@ -438,12 +438,12 @@ public abstract class JDBC3DatabaseMetaData extends CoreDatabaseMetaData {
 
     /** @see java.sql.DatabaseMetaData#supportsAlterTableWithAddColumn() */
     public boolean supportsAlterTableWithAddColumn() {
-        return false;
+        return true;
     }
 
     /** @see java.sql.DatabaseMetaData#supportsAlterTableWithDropColumn() */
     public boolean supportsAlterTableWithDropColumn() {
-        return false;
+        return true;
     }
 
     /** @see java.sql.DatabaseMetaData#supportsANSI92EntryLevelSQL() */
@@ -964,14 +964,14 @@ public abstract class JDBC3DatabaseMetaData extends CoreDatabaseMetaData {
                         try {
                             rsColAutoinc.close();
                         } catch (Exception e) {
-                            LogHolder.logger.error("Could not close ResultSet", e);
+                            LogHolder.logger.error(() -> "Could not close ResultSet", e);
                         }
                     }
                     if (statColAutoinc != null) {
                         try {
                             statColAutoinc.close();
                         } catch (Exception e) {
-                            LogHolder.logger.error("Could not close statement", e);
+                            LogHolder.logger.error(() -> "Could not close statement", e);
                         }
                     }
                 }
@@ -1057,10 +1057,10 @@ public abstract class JDBC3DatabaseMetaData extends CoreDatabaseMetaData {
                                 }
                                 // try to parse the values
                                 try {
-                                    int iInteger = Integer.parseUnsignedInt(sInteger);
+                                    int iInteger = Integer.parseUnsignedInt(sInteger.trim());
                                     // parse decimals?
                                     if (sDecimal != null) {
-                                        iDecimalDigits = Integer.parseUnsignedInt(sDecimal);
+                                        iDecimalDigits = Integer.parseUnsignedInt(sDecimal.trim());
                                         // columns size equals sum of integer and decimal part
                                         // of dimension
                                         iColumnSize = iInteger + iDecimalDigits;
@@ -1125,7 +1125,7 @@ public abstract class JDBC3DatabaseMetaData extends CoreDatabaseMetaData {
                 try {
                     rs.close();
                 } catch (Exception e) {
-                    LogHolder.logger.error("Could not close ResultSet", e);
+                    LogHolder.logger.error(() -> "Could not close ResultSet", e);
                 }
             }
         }
