@@ -1,8 +1,7 @@
 package org.sqlite;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.fail;
 
 import java.sql.Connection;
 import java.sql.DriverManager;
@@ -11,6 +10,8 @@ import java.sql.Statement;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.sqlite.core.DB;
+import org.sqlite.core.NativeDBHelper;
 
 public class ProgressHandlerTest {
     private Connection conn;
@@ -46,13 +47,13 @@ public class ProgressHandlerTest {
                 1,
                 new ProgressHandler() {
                     @Override
-                    protected int progress() throws SQLException {
+                    protected int progress() {
                         calls[0]++;
                         return 0;
                     }
                 });
         workWork();
-        assertTrue(calls[0] > 0);
+        assertThat(calls[0]).isGreaterThan(0);
     }
 
     @Test
@@ -63,21 +64,21 @@ public class ProgressHandlerTest {
                 1,
                 new ProgressHandler() {
                     @Override
-                    protected int progress() throws SQLException {
+                    protected int progress() {
                         calls[0]++;
                         return 0;
                     }
                 });
         workWork();
-        assertTrue(calls[0] > 0);
+        assertThat(calls[0]).isGreaterThan(0);
         int totalCalls = calls[0];
         ProgressHandler.clearHandler(conn);
         workWork();
-        assertEquals(totalCalls, calls[0]);
+        assertThat(calls[0]).isEqualTo(totalCalls);
     }
 
     @Test
-    public void testInterrupt() throws Exception {
+    public void testInterrupt() {
 
         try {
             ProgressHandler.setHandler(
@@ -85,7 +86,7 @@ public class ProgressHandlerTest {
                     1,
                     new ProgressHandler() {
                         @Override
-                        protected int progress() throws SQLException {
+                        protected int progress() {
                             return 1;
                         }
                     });
@@ -95,6 +96,46 @@ public class ProgressHandlerTest {
             return;
         }
         // Progress function throws, not reached
-        fail();
+        fail("Progress function throws, not reached");
+    }
+
+    /**
+     * Tests that clear progress helper is implemented as expected. Ensures that memory is free'd
+     * and free'd pointers are set to null (0)
+     *
+     * @throws Exception on test failure
+     */
+    @Test
+    public void testClearProgressHelper() throws Exception {
+        SQLiteConnection sqliteConnection = (SQLiteConnection) conn;
+        final DB database = sqliteConnection.getDatabase();
+        setDummyHandler();
+        assertThat(NativeDBHelper.getProgressHandler(database)).isNotEqualTo(0);
+        ProgressHandler.clearHandler(conn);
+        assertThat(NativeDBHelper.getProgressHandler(database)).isEqualTo(0);
+        ProgressHandler.clearHandler(conn);
+
+        setDummyHandler();
+        assertThat(NativeDBHelper.getProgressHandler(database)).isNotEqualTo(0);
+        ProgressHandler.setHandler(conn, 1, null);
+        assertThat(NativeDBHelper.getProgressHandler(database)).isEqualTo(0);
+        ProgressHandler.setHandler(conn, 1, null);
+
+        setDummyHandler();
+        assertThat(NativeDBHelper.getProgressHandler(database)).isNotEqualTo(0);
+        conn.close();
+        assertThat(NativeDBHelper.getProgressHandler(database)).isEqualTo(0);
+    }
+
+    private void setDummyHandler() throws SQLException {
+        ProgressHandler.setHandler(
+                conn,
+                1,
+                new ProgressHandler() {
+                    @Override
+                    protected int progress() {
+                        return 0;
+                    }
+                });
     }
 }
