@@ -12,7 +12,6 @@ import java.sql.Savepoint;
 import java.sql.Statement;
 import java.util.Properties;
 import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
@@ -26,14 +25,6 @@ public class SavepointTest {
     private Connection conn1, conn2;
     private Statement stat1, stat2;
 
-    @BeforeAll
-    public static void forName() throws Exception {
-        System.out.println(
-                "running in "
-                        + (SQLiteJDBCLoader.isNativeMode() ? "native" : "pure-java")
-                        + " mode");
-    }
-
     @BeforeEach
     public void connect(@TempDir File tempDir) throws Exception {
         File tmpFile = File.createTempFile("test-trans", ".db", tempDir);
@@ -66,7 +57,7 @@ public class SavepointTest {
 
         assertThat(stat1.executeUpdate("insert into trans values (4);")).isEqualTo(1);
 
-        // transaction not yet commited, conn1 can see, conn2 can not
+        // transaction not yet committed, conn1 can see, conn2 can not
         rs = stat1.executeQuery(countSql);
         assertThat(rs.next()).isTrue();
         assertThat(rs.getInt(1)).isEqualTo(1);
